"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = (0, tslib_1.__importDefault)(require("fs"));
const schema_1 = require("@graphql-tools/schema");
const graphql_scalars_1 = require("graphql-scalars");
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const mock_1 = require("@graphql-tools/mock");
const logger_1 = require("./logger");
const graphql_tag_1 = require("graphql-tag");
const validator_1 = require("./validator");
const typeDefs = fs_1.default.readFileSync(path_1.default.join(__dirname, "../data/events.graphql"), {
    encoding: "utf-8",
});
const builtSchema = (0, schema_1.makeExecutableSchema)({
    typeDefs,
    resolvers: {
        DateTime: graphql_scalars_1.DateTimeResolver,
        EmailAddress: graphql_scalars_1.EmailAddressResolver,
        UUID: graphql_scalars_1.UUIDResolver,
    },
});
const mockSchema = (0, mock_1.addMocksToSchema)({
    schema: builtSchema,
    mocks: graphql_scalars_1.mocks,
});
const validator = new validator_1.Validator(mockSchema);
describe("validate", () => {
    test("correct data does not throw", () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
        const key = "ClosedGroupJoinRequestResponseEvent";
        const data = validator.sample("ClosedGroupJoinRequestResponseEvent");
        validator.validate(key, data.data[key]);
    }));
    test("incorrect data throws", () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
        const key = "ClosedGroupJoinRequestResponseEvent";
        const data = {
            id: "12321",
        };
        expect(() => validator.validate(key, data)).toThrow();
    }));
    test("incorrect nonUUID throws", () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
        const key = "EntityFlagEvent";
        const data = validator.sample(key).data[key];
        data.entityId = "non-uuid";
        expect(() => validator.validate(key, data)).toThrow();
    }));
});
describe("decodeData", () => {
    test("correct data works", () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
        const key = "ClosedGroupJoinRequestResponseEvent";
        const data = validator.sample(key).data[key];
        const query = (0, graphql_tag_1.gql) `
      query {
        boom: ClosedGroupJoinRequestResponseEvent {
          renameId: id
          ...A
        }
      }
      fragment A on ClosedGroupJoinRequestResponseEvent {
        requestedByUserId
        status
      }
    `;
        const logger = (0, logger_1.getLogger)();
        const result = validator.extract(query, key, data, logger);
        expect(result.data).toMatchObject({
            boom: {
                renameId: data.id,
                requestedByUserId: data.requestedByUserId,
            },
        });
    }));
});
describe("sample", () => {
    test("correct data works", () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
        var _a, _b;
        const store = new mock_1.MockStore({
            schema: builtSchema,
            mocks: graphql_scalars_1.mocks,
        });
        const mockSchema = (0, mock_1.addMocksToSchema)({
            schema: builtSchema,
            preserveResolvers: true,
            store,
        });
        const mockValidator = new validator_1.Validator(mockSchema);
        const result = mockValidator.sample("EntityFlagEvent");
        store.reset();
        const result2 = mockValidator.sample("EntityFlagEvent");
        expect((_a = result.data) === null || _a === void 0 ? void 0 : _a["EntityFlagEvent"].id).not.toEqual((_b = result2.data) === null || _b === void 0 ? void 0 : _b["EntityFlagEvent"].id);
    }));
});
